# from sense_hat import SenseHat
# from Graph import Graph
#
# min_temp = 20
# max_temp = 24
# sense = SenseHat()
# g = Graph(min_temp, max_temp)
# current_temp = sense.get_temperature()
# pixels = g.render(current_temp)
# sense.set_pixels(pixels)

